@@ -143,7 +143,7 @@ dt_timeofday = dt.timedelta(hours=16)
 
 # Get a list of trading days between the start and the end.
 ldt_timestamps = du.getNYSEdays(dt_start, dt_end, dt_timeofday)
-ls_symbols = ['MSFT', 'GOOG', 'ML4T-010']
+ls_symbols = ['MSFT', 'GOOG']
 
 # Creating an object of the dataaccess class with Yahoo as the source.
 c_dataobj = da.DataAccess('Yahoo', verbose=True)
@@ -153,16 +153,16 @@ print df_close
 print
 print "\nCorrect Output using the Default Data should be : "
 print "Assignments use this data for grading"
-print "                      MSFT    GOOG    ML4T-010"
-print "2012-02-10 16:00:00  29.90  605.91  107.366472"
-print "2012-02-13 16:00:00  29.98  612.20  107.747166"
-print "2012-02-14 16:00:00  29.86  609.76  108.041904"
-print "2012-02-15 16:00:00  29.66  605.56  108.244801"
-print "2012-02-16 16:00:00  30.88  606.52  108.351808"
-print "2012-02-17 16:00:00  30.84  604.64  108.360787"
-print "2012-02-21 16:00:00  31.03  614.00  108.271560"
-print "2012-02-22 16:00:00  30.86  607.94  108.085909"
-print "2012-02-23 16:00:00  30.96  606.11  107.807538"
+print "                      MSFT    GOOG"
+print "2012-02-10 16:00:00  29.90  605.91"
+print "2012-02-13 16:00:00  29.98  612.20"
+print "2012-02-14 16:00:00  29.86  609.76"
+print "2012-02-15 16:00:00  29.66  605.56"
+print "2012-02-16 16:00:00  30.88  606.52"
+print "2012-02-17 16:00:00  30.84  604.64"
+print "2012-02-21 16:00:00  31.03  614.00"
+print "2012-02-22 16:00:00  30.86  607.94"
+print "2012-02-23 16:00:00  30.96  606.11"
 print
 
 dt_test = dt.datetime(2012, 2, 15, 16)
