@@ -1,13 +1,13 @@
 #
 # (c) 2011, 2012 Georgia Tech Research Corporation
-# This source code is released under the New BSD license.  
+# This source code is released under the New BSD license.
 # Please see http://wiki.quantsoftware.org/index.php?title=QSTK_License
 # for license details.
 
 # Created on Jan 16, 2013
 
 # @author: Sourabh Bajaj
-# @contact: sourabhbajaj90@gmail.com
+# @contact: sourabh@sourabhbajaj.com
 # @summary: Ubuntu Installation script of QSTK
 #
 
@@ -31,9 +31,9 @@ echo "Installing dependencies - pandas"
 sudo pip install pandas
 # echo "Installing dependencies - PYQT4"
 # sudo apt-get install python-qt4
-echo "Installing dependencies - CVXOPT"
-sudo apt-get --yes --force-yes build-dep python-cvxopt
-sudo apt-get --yes --force-yes install python-cvxopt
+# echo "Installing dependencies - CVXOPT"
+# sudo apt-get --yes --force-yes build-dep python-cvxopt
+# sudo apt-get --yes --force-yes install python-cvxopt
 echo "Install Unzip"
 sudo apt-get --yes --force-yes install unzip
 
